http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/ComputeProjectionExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeProjectionExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeProjectionExample.java
index 600d5c8..463dd48 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeProjectionExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeProjectionExample.java
@@ -29,7 +29,7 @@ public class ComputeProjectionExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         try (Ignite ignite = 
Ignition.start("examples/config/example-compute.xml")) {
@@ -71,9 +71,9 @@ public class ComputeProjectionExample {
      *
      * @param ignite Grid.
      * @param prj Grid projection.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void sayHello(Ignite ignite, final ClusterGroup prj) throws 
GridException {
+    private static void sayHello(Ignite ignite, final ClusterGroup prj) throws 
IgniteCheckedException {
         // Print out hello message on all projection nodes.
         ignite.compute(prj).broadcast(
             new IgniteRunnable() {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/ComputeReducerExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeReducerExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeReducerExample.java
index 731b021..9f0b5c7 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeReducerExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeReducerExample.java
@@ -34,9 +34,9 @@ public class ComputeReducerExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-compute.xml")) 
{
             System.out.println();
             System.out.println("Compute reducer example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
index 66b6935..20e986e 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
@@ -30,9 +30,9 @@ public class ComputeRunnableExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-compute.xml")) 
{
             System.out.println();
             System.out.println("Compute runnable example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
index 1b5ba47..e80e1f2 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeScheduleExample.java
@@ -33,9 +33,9 @@ public class ComputeScheduleExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-compute.xml")) 
{
             System.out.println();
             System.out.println("Compute schedule example started.");
@@ -58,8 +58,8 @@ public class ComputeScheduleExample {
                                 }
                             );
                         }
-                        catch (GridException e) {
-                            throw new GridRuntimeException(e);
+                        catch (IgniteCheckedException e) {
+                            throw new IgniteException(e);
                         }
 
                         return invocations;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskMapExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskMapExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskMapExample.java
index 22eaecf..484f3e9 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskMapExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskMapExample.java
@@ -28,9 +28,9 @@ public class ComputeTaskMapExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-compute.xml")) 
{
             System.out.println();
             System.out.println("Compute task map example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskSplitExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskSplitExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskSplitExample.java
index 6bf3257..8dfcdc2 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskSplitExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeTaskSplitExample.java
@@ -26,9 +26,9 @@ public class ComputeTaskSplitExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-compute.xml")) 
{
             System.out.println();
             System.out.println("Compute task split example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
index b9395c3..dff46a3 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverExample.java
@@ -32,9 +32,9 @@ public class ComputeFailoverExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = 
Ignition.start(ComputeFailoverNodeStartup.configuration())) {
             if (!ExamplesUtils.checkMinTopologySize(g.cluster(), 2))
                 return;
@@ -119,7 +119,7 @@ public class ComputeFailoverExample {
 
                 return sum;
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 throw new GridClosureException(e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverNodeStartup.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverNodeStartup.java
 
b/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverNodeStartup.java
index eb25eca..a892cc9 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverNodeStartup.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/failover/ComputeFailoverNodeStartup.java
@@ -29,9 +29,9 @@ public class ComputeFailoverNodeStartup {
      * Start up an empty node with specified configuration.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         Ignition.start(configuration());
     }
 
@@ -39,9 +39,9 @@ public class ComputeFailoverNodeStartup {
      * Create Grid configuration with configured checkpoints.
      *
      * @return Grid configuration.
-     * @throws GridException If configuration creation failed.
+     * @throws IgniteCheckedException If configuration creation failed.
      */
-    public static IgniteConfiguration configuration() throws GridException {
+    public static IgniteConfiguration configuration() throws 
IgniteCheckedException {
         IgniteConfiguration cfg = new IgniteConfiguration();
 
         cfg.setLocalHost("127.0.0.1");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/compute/montecarlo/CreditRiskExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/montecarlo/CreditRiskExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/montecarlo/CreditRiskExample.java
index db82a0d..07239db 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/montecarlo/CreditRiskExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/montecarlo/CreditRiskExample.java
@@ -30,9 +30,9 @@ public final class CreditRiskExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-compute.xml")) 
{
             System.out.println();
             System.out.println("Credit risk example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CacheAffinityExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheAffinityExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheAffinityExample.java
index eac9780..7f27753 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheAffinityExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheAffinityExample.java
@@ -39,9 +39,9 @@ public final class CacheAffinityExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache affinity example started.");
@@ -66,9 +66,9 @@ public final class CacheAffinityExample {
      * Collocates jobs with keys they need to work on using {@link 
org.apache.ignite.IgniteCompute#affinityRun(String, Object, Runnable)}
      * method.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void visitUsingAffinityRun() throws GridException {
+    private static void visitUsingAffinityRun() throws IgniteCheckedException {
         Ignite g = Ignition.ignite();
 
         final GridCache<Integer, String> cache = g.cache(CACHE_NAME);
@@ -94,9 +94,9 @@ public final class CacheAffinityExample {
      * method. The difference from {@code affinityRun(...)} method is that 
here we process multiple keys
      * in a single job.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void visitUsingMapKeysToNodes() throws GridException {
+    private static void visitUsingMapKeysToNodes() throws 
IgniteCheckedException {
         final Ignite g = Ignition.ignite();
 
         Collection<Integer> keys = new ArrayList<>(KEY_CNT);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
index 9ce1c1e..a30c20f 100644
--- a/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
+++ b/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
@@ -33,9 +33,9 @@ public class CacheApiExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
      * @throws GridException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache API example started.");
@@ -55,9 +55,9 @@ public class CacheApiExample {
      * Demonstrates cache operations similar to {@link ConcurrentMap} API. 
Note that
      * cache API is a lot richer than the JDK {@link ConcurrentMap}.
      *
      * @throws GridException If failed.
      */
-    private static void atomicMapOperations() throws GridException {
+    private static void atomicMapOperations() throws IgniteCheckedException {
         System.out.println();
         System.out.println(">>> Cache atomic map operation examples.");
 
@@ -80,7 +80,7 @@ public class CacheApiExample {
                 try {
                     System.out.println("Put operation completed 
[previous-value=" + fut.get() + ']');
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     e.printStackTrace();
                 }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CacheContinuousQueryExample.java
----------------------------------------------------------------------
@@ -33,9 +33,9 @@ public class CacheApiExample {
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
@@ -55,9 +55,9 @@ public class CacheApiExample {
      * cache API is a lot richer than the JDK {@link ConcurrentMap}.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheContinuousQueryExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheContinuousQueryExample.java
index 42ee832..b42baef 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheContinuousQueryExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheContinuousQueryExample.java
@@ -34,9 +34,9 @@ public class CacheContinuousQueryExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException, 
InterruptedException {
+    public static void main(String[] args) throws IgniteCheckedException, 
InterruptedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache continuous query example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CacheDataLoaderExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheDataLoaderExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheDataLoaderExample.java
index eeead17..e238ea5 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheDataLoaderExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheDataLoaderExample.java
@@ -39,7 +39,7 @@ public class CacheDataLoaderExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         ExamplesUtils.checkMinMemory(MIN_MEMORY);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CacheEventsExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheEventsExample.java 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheEventsExample.java
index 75d837f..6437352 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheEventsExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheEventsExample.java
@@ -37,9 +37,9 @@ public class CacheEventsExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException, 
InterruptedException {
+    public static void main(String[] args) throws IgniteCheckedException, 
InterruptedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache events example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CacheNodeStartup.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheNodeStartup.java 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheNodeStartup.java
index 37800c5..7d40c834 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheNodeStartup.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheNodeStartup.java
@@ -20,9 +20,9 @@ public class CacheNodeStartup {
      * Start up an empty node with specified cache configuration.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         Ignition.start("examples/config/example-cache.xml");
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
index 7bddbbd..69a1216 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CachePopularNumbersExample.java
@@ -48,7 +48,7 @@ public class CachePopularNumbersExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         Timer popularNumbersQryTimer = new Timer("numbers-query-worker");
@@ -83,9 +83,9 @@ public class CachePopularNumbersExample {
      * Populates cache in real time with numbers and keeps count for every 
number.
      *
      * @param g Grid.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void streamData(final Ignite g) throws GridException {
+    private static void streamData(final Ignite g) throws 
IgniteCheckedException {
         try (IgniteDataLoader<Integer, Long> ldr = g.dataLoader(CACHE_NAME)) {
             // Set larger per-node buffer size since our state is relatively 
small.
             ldr.perNodeBufferSize(2048);
@@ -137,7 +137,7 @@ public class CachePopularNumbersExample {
 
                     System.out.println("----------------");
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     e.printStackTrace();
                 }
             }
@@ -160,7 +160,7 @@ public class CachePopularNumbersExample {
         };
 
         /** {@inheritDoc} */
-        @Override public void update(GridCache<Integer, Long> cache, 
Collection<Map.Entry<Integer, Long>> entries) throws GridException {
+        @Override public void update(GridCache<Integer, Long> cache, 
Collection<Map.Entry<Integer, Long>> entries) throws IgniteCheckedException {
             for (Map.Entry<Integer, Long> entry : entries)
                 cache.transform(entry.getKey(), INC);
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CachePutGetExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CachePutGetExample.java 
b/examples/src/main/java/org/gridgain/examples/datagrid/CachePutGetExample.java
index a58f247..a1bb470 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CachePutGetExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CachePutGetExample.java
@@ -32,7 +32,7 @@ public class CachePutGetExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
@@ -50,9 +50,9 @@ public class CachePutGetExample {
     /**
      * Execute individual puts and gets.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void putGet() throws GridException {
+    private static void putGet() throws IgniteCheckedException {
         System.out.println();
         System.out.println(">>> Cache put-get example started.");
 
@@ -75,9 +75,9 @@ public class CachePutGetExample {
     /**
      * Execute bulk {@code putAll(...)} and {@code getAll(...)} operations.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void putAllGetAll() throws GridException {
+    private static void putAllGetAll() throws IgniteCheckedException {
         System.out.println();
         System.out.println(">>> Starting putAll-getAll example.");
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CacheQueryExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheQueryExample.java 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheQueryExample.java
index 6236a41..27c23c9 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheQueryExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheQueryExample.java
@@ -65,7 +65,7 @@ public class CacheQueryExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
@@ -109,9 +109,9 @@ public class CacheQueryExample {
     /**
      * Example for SQL queries based on salary ranges.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
-    private static void sqlQuery() throws GridException {
+    private static void sqlQuery() throws IgniteCheckedException {
         GridCache<GridCacheAffinityKey<UUID>, Person> cache = 
Ignition.ignite().cache(CACHE_NAME);
 
         // Create query which selects salaries based on range.
@@ -129,9 +129,9 @@ public class CacheQueryExample {
     /**
      * Example for SQL queries based on all employees working for a specific 
organization.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
-    private static void sqlQueryWithJoin() throws GridException {
+    private static void sqlQueryWithJoin() throws IgniteCheckedException {
         GridCache<GridCacheAffinityKey<UUID>, Person> cache = 
Ignition.ignite().cache(CACHE_NAME);
 
         // Create query which joins on 2 types to select people for a specific 
organization.
@@ -148,9 +148,9 @@ public class CacheQueryExample {
     /**
      * Example for TEXT queries using LUCENE-based indexing of people's 
resumes.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
-    private static void textQuery() throws GridException {
+    private static void textQuery() throws IgniteCheckedException {
         GridCache<GridCacheAffinityKey<UUID>, Person> cache = 
Ignition.ignite().cache(CACHE_NAME);
 
         //  Query for all people with "Master Degree" in their resumes.
@@ -169,9 +169,9 @@ public class CacheQueryExample {
      * Example for SQL queries with custom remote and local reducers to 
calculate
      * average salary for a specific organization.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
-    private static void sqlQueryWithReducers() throws GridException {
+    private static void sqlQueryWithReducers() throws IgniteCheckedException {
         GridCacheProjection<GridCacheAffinityKey<UUID>, Person> cache = 
Ignition.ignite().cache(CACHE_NAME);
 
         // Calculate average of salary of all persons in GridGain.
@@ -218,9 +218,9 @@ public class CacheQueryExample {
      * Example for SQL queries with custom transformer to allow passing
      * only the required set of fields back to caller.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
-    private static void sqlQueryWithTransformer() throws GridException {
+    private static void sqlQueryWithTransformer() throws 
IgniteCheckedException {
         GridCache<GridCacheAffinityKey<UUID>, Person> cache = 
Ignition.ignite().cache(CACHE_NAME);
 
         // Create query to get names of all employees working for some company.
@@ -247,9 +247,9 @@ public class CacheQueryExample {
      * Example for SQL-based fields queries that return only required
      * fields instead of whole key-value pairs.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
-    private static void sqlFieldsQuery() throws GridException {
+    private static void sqlFieldsQuery() throws IgniteCheckedException {
         GridCache<?, ?> cache = Ignition.ignite().cache(CACHE_NAME);
 
         // Create query to get names of all employees.
@@ -268,9 +268,9 @@ public class CacheQueryExample {
      * Example for SQL-based fields queries that return only required
      * fields instead of whole key-value pairs.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
-    private static void sqlFieldsQueryWithJoin() throws GridException {
+    private static void sqlFieldsQueryWithJoin() throws IgniteCheckedException 
{
         GridCache<?, ?> cache = Ignition.ignite().cache(CACHE_NAME);
 
         // Create query to get names of all employees.
@@ -289,10 +289,10 @@ public class CacheQueryExample {
     /**
      * Populate cache with test data.
      *
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      * @throws InterruptedException In case of error.
      */
-    private static void initialize() throws GridException, 
InterruptedException {
+    private static void initialize() throws IgniteCheckedException, 
InterruptedException {
         GridCache<?, ?> cache = Ignition.ignite().cache(CACHE_NAME);
 
         // Organization projection.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/CacheTransactionExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheTransactionExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheTransactionExample.java
index ababe9d..f6d4cc7 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheTransactionExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheTransactionExample.java
@@ -36,9 +36,9 @@ public class CacheTransactionExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache transaction example started.");
@@ -75,9 +75,9 @@ public class CacheTransactionExample {
      *
      * @param acctId Account ID.
      * @param amount Amount to deposit.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void deposit(int acctId, double amount) throws 
GridException {
+    private static void deposit(int acctId, double amount) throws 
IgniteCheckedException {
         // Clone every object we get from cache, so we can freely update it.
         GridCacheProjection<Integer, Account> cache = 
Ignition.ignite().<Integer, Account>cache(CACHE_NAME).flagsOn(CLONE);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicLongExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicLongExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicLongExample.java
index 0d85bf6..42a2b92 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicLongExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicLongExample.java
@@ -37,9 +37,9 @@ public final class CacheAtomicLongExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache atomic long example started.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
index a86a454..852c03a 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicReferenceExample.java
@@ -34,9 +34,9 @@ public final class CacheAtomicReferenceExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache atomic reference example started.");
@@ -111,8 +111,8 @@ public final class CacheAtomicReferenceExample {
 
                 System.out.println("Atomic reference value is " + ref.get() + 
'.');
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
index 0507161..393aff3 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicSequenceExample.java
@@ -37,9 +37,9 @@ public final class CacheAtomicSequenceExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache atomic sequence example started.");
@@ -97,8 +97,8 @@ public final class CacheAtomicSequenceExample {
                         seq.incrementAndGet() + ']');
 
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicStampedExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicStampedExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicStampedExample.java
index 5be5de7..0079c59 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicStampedExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheAtomicStampedExample.java
@@ -34,9 +34,9 @@ public final class CacheAtomicStampedExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache atomic stamped example started.");
@@ -117,8 +117,8 @@ public final class CacheAtomicStampedExample {
 
                 System.out.println("Atomic stamped [value=" + stamped.value() 
+ ", stamp=" + stamped.stamp() + ']');
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheCountDownLatchExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheCountDownLatchExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheCountDownLatchExample.java
index 96767fb..9ca5beb 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheCountDownLatchExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheCountDownLatchExample.java
@@ -37,7 +37,7 @@ public class CacheCountDownLatchExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
@@ -97,7 +97,7 @@ public class CacheCountDownLatchExample {
 
                 System.out.println("Counted down [newCnt=" + newCnt + ", 
nodeId=" + Ignition.ignite().cluster().localNode().id() + ']');
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 throw new RuntimeException(e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheQueueExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheQueueExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheQueueExample.java
index 5a4a803..cd7e785 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheQueueExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheQueueExample.java
@@ -41,9 +41,9 @@ public class CacheQueueExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache queue example started.");
@@ -69,9 +69,9 @@ public class CacheQueueExample {
      * @param g Grid.
      * @param queueName Name of queue.
      * @return Queue.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
-    private static GridCacheQueue<String> initializeQueue(Ignite g, String 
queueName) throws GridException {
+    private static GridCacheQueue<String> initializeQueue(Ignite g, String 
queueName) throws IgniteCheckedException {
         // Initialize new FIFO queue.
         GridCacheQueue<String> queue = 
g.cache(CACHE_NAME).dataStructures().queue(queueName, 0, false, true);
 
@@ -89,9 +89,9 @@ public class CacheQueueExample {
      * Read items from head and tail of queue.
      *
      * @param g Grid.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void readFromQueue(Ignite g) throws GridException {
+    private static void readFromQueue(Ignite g) throws IgniteCheckedException {
         final String queueName = queue.name();
 
         // Read queue items on each node.
@@ -104,9 +104,9 @@ public class CacheQueueExample {
      * Write items into queue.
      *
      * @param g Grid.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void writeToQueue(Ignite g) throws GridException {
+    private static void writeToQueue(Ignite g) throws IgniteCheckedException {
         final String queueName = queue.name();
 
         // Write queue items on each node.
@@ -126,9 +126,9 @@ public class CacheQueueExample {
      * Clear and remove queue.
      *
      * @param g Grid.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
-    private static void clearAndRemoveQueue(Ignite g) throws GridException {
+    private static void clearAndRemoveQueue(Ignite g) throws 
IgniteCheckedException {
         System.out.println("Queue size before clearing: " + queue.size());
 
         // Clear queue.
@@ -143,7 +143,7 @@ public class CacheQueueExample {
         try {
             queue.poll();
         }
-        catch (GridRuntimeException expected) {
+        catch (IgniteException expected) {
             System.out.println("Expected exception - " + 
expected.getMessage());
         }
     }
@@ -199,7 +199,7 @@ public class CacheQueueExample {
                         System.out.println("Queue item has been read from 
queue head: " + queue.poll());
                 }
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 throw new RuntimeException(e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheSetExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheSetExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheSetExample.java
index d06c2c5..53218a4 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheSetExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/datastructures/CacheSetExample.java
@@ -37,9 +37,9 @@ public class CacheSetExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         try (Ignite g = Ignition.start("examples/config/example-cache.xml")) {
             System.out.println();
             System.out.println(">>> Cache set example started.");
@@ -63,9 +63,9 @@ public class CacheSetExample {
      * @param g Grid.
      * @param setName Name of set.
      * @return Set.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
-    private static GridCacheSet<String> initializeSet(Ignite g, String 
setName) throws GridException {
+    private static GridCacheSet<String> initializeSet(Ignite g, String 
setName) throws IgniteCheckedException {
         // Initialize new set.
         GridCacheSet<String> set = 
g.cache(CACHE_NAME).dataStructures().set(setName, false, true);
 
@@ -82,9 +82,9 @@ public class CacheSetExample {
      * Write items into set.
      *
      * @param g Grid.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void writeToSet(Ignite g) throws GridException {
+    private static void writeToSet(Ignite g) throws IgniteCheckedException {
         final String setName = set.name();
 
         // Write set items on each node.
@@ -120,9 +120,9 @@ public class CacheSetExample {
      * Clear and remove set.
      *
      * @param g Grid.
-     * @throws GridException If execution failed.
+     * @throws IgniteCheckedException If execution failed.
      */
-    private static void clearAndRemoveSet(Ignite g) throws GridException {
+    private static void clearAndRemoveSet(Ignite g) throws 
IgniteCheckedException {
         System.out.println("Set size before clearing: " + set.size());
 
         // Clear set.
@@ -139,7 +139,7 @@ public class CacheSetExample {
         try {
             set.contains("1");
         }
-        catch (GridRuntimeException expected) {
+        catch (IgniteException expected) {
             System.out.println("Expected exception - " + 
expected.getMessage());
         }
     }
@@ -178,7 +178,7 @@ public class CacheSetExample {
                     System.out.println("Set item has been added: " + item);
                 }
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 throw new RuntimeException(e);
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExample.java
index 380b022..be206a0 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExample.java
@@ -73,9 +73,9 @@ public class HibernateL2CacheExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         // Start the GridGain node, run the example, and stop the node when 
finished.
         try (Ignite g = 
Ignition.start(HibernateL2CacheExampleNodeStartup.configuration())) {
             // We use a single session factory, but create a dedicated session

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExampleNodeStartup.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExampleNodeStartup.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExampleNodeStartup.java
index e7d5a97..c19806f 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExampleNodeStartup.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/hibernate/HibernateL2CacheExampleNodeStartup.java
@@ -30,9 +30,9 @@ public class HibernateL2CacheExampleNodeStartup {
      * Start up an empty node with specified cache configuration.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         Ignition.start(configuration());
     }
 
@@ -40,9 +40,9 @@ public class HibernateL2CacheExampleNodeStartup {
      * Create Grid configuration with GGFS and enabled IPC.
      *
      * @return Grid configuration.
-     * @throws GridException If configuration creation failed.
+     * @throws IgniteCheckedException If configuration creation failed.
      */
-    public static IgniteConfiguration configuration() throws GridException {
+    public static IgniteConfiguration configuration() throws 
IgniteCheckedException {
         IgniteConfiguration cfg = new IgniteConfiguration();
 
         cfg.setGridName("hibernate-grid");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/starschema/CacheStarSchemaExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/starschema/CacheStarSchemaExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/starschema/CacheStarSchemaExample.java
index 174e1e0..ff5502d 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/starschema/CacheStarSchemaExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/starschema/CacheStarSchemaExample.java
@@ -54,7 +54,7 @@ public class CacheStarSchemaExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         Ignite g = Ignition.start("examples/config/example-cache.xml");
@@ -82,9 +82,9 @@ public class CacheStarSchemaExample {
      * Populate cache with {@code 'dimensions'} which in our case are
      * {@link DimStore} and {@link DimProduct} instances.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void populateDimensions() throws GridException {
+    private static void populateDimensions() throws IgniteCheckedException {
         GridCache<Integer, Object> cache = 
Ignition.ignite().cache(REPLICATED_CACHE_NAME);
 
         DimStore store1 = new DimStore(idGen++, "Store1", "12345", "321 Chilly 
Dr, NY");
@@ -105,9 +105,9 @@ public class CacheStarSchemaExample {
     /**
      * Populate cache with {@code 'facts'}, which in our case are {@link 
FactPurchase} objects.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void populateFacts() throws GridException {
+    private static void populateFacts() throws IgniteCheckedException {
         GridCache<Integer, Object> dimCache = 
Ignition.ignite().cache(REPLICATED_CACHE_NAME);
         GridCache<Integer, Object> factCache = 
Ignition.ignite().cache(PARTITIONED_CACHE_NAME);
 
@@ -129,9 +129,9 @@ public class CacheStarSchemaExample {
      * between {@link DimStore} objects stored in {@code 'replicated'} cache 
and
      * {@link FactPurchase} objects stored in {@code 'partitioned'} cache.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void queryStorePurchases() throws GridException {
+    private static void queryStorePurchases() throws IgniteCheckedException {
         GridCache<Integer, FactPurchase> factCache = 
Ignition.ignite().cache(PARTITIONED_CACHE_NAME);
 
         // All purchases for store1.
@@ -153,9 +153,9 @@ public class CacheStarSchemaExample {
      * objects stored in {@code 'replicated'} cache and {@link FactPurchase} 
objects
      * stored in {@code 'partitioned'} cache.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void queryProductPurchases() throws GridException {
+    private static void queryProductPurchases() throws IgniteCheckedException {
         GridCache<Integer, Object> dimCache = 
Ignition.ignite().cache(REPLICATED_CACHE_NAME);
         GridCache<Integer, FactPurchase> factCache = 
Ignition.ignite().cache(PARTITIONED_CACHE_NAME);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheNodeWithStoreStartup.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheNodeWithStoreStartup.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheNodeWithStoreStartup.java
index 0737c05..b8bf277 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheNodeWithStoreStartup.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheNodeWithStoreStartup.java
@@ -30,9 +30,9 @@ public class CacheNodeWithStoreStartup {
      * Start up an empty node with specified cache configuration.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         Ignition.start(configure());
     }
 
@@ -40,9 +40,9 @@ public class CacheNodeWithStoreStartup {
      * Configure grid.
      *
      * @return Grid configuration.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    public static IgniteConfiguration configure() throws GridException {
+    public static IgniteConfiguration configure() throws 
IgniteCheckedException {
         IgniteConfiguration cfg = new IgniteConfiguration();
 
         cfg.setLocalHost("127.0.0.1");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreExample.java
index 30c0b45..f33b463 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreExample.java
@@ -31,7 +31,7 @@ public class CacheStoreExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         IgniteConfiguration cfg = CacheNodeWithStoreStartup.configure();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreLoadDataExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreLoadDataExample.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreLoadDataExample.java
index a31b802..7a0d4b0 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreLoadDataExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/CacheStoreLoadDataExample.java
@@ -35,7 +35,7 @@ public class CacheStoreLoadDataExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         ExamplesUtils.checkMinMemory(MIN_MEMORY);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/store/dummy/CacheDummyPersonStore.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/dummy/CacheDummyPersonStore.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/dummy/CacheDummyPersonStore.java
index 7b46dc3..8706873 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/dummy/CacheDummyPersonStore.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/dummy/CacheDummyPersonStore.java
@@ -37,28 +37,28 @@ public class CacheDummyPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
     private Map<Long, Person> dummyDB = new ConcurrentHashMap<>();
 
     /** {@inheritDoc} */
-    @Override public Person load(@Nullable GridCacheTx tx, Long key) throws 
GridException {
+    @Override public Person load(@Nullable GridCacheTx tx, Long key) throws 
IgniteCheckedException {
         System.out.println(">>> Store load [key=" + key + ", xid=" + (tx == 
null ? null : tx.xid()) + ']');
 
         return dummyDB.get(key);
     }
 
     /** {@inheritDoc} */
-    @Override public void put(@Nullable GridCacheTx tx, Long key, Person val) 
throws GridException {
+    @Override public void put(@Nullable GridCacheTx tx, Long key, Person val) 
throws IgniteCheckedException {
         System.out.println(">>> Store put [key=" + key + ", val=" + val + ", 
xid=" + (tx == null ? null : tx.xid()) + ']');
 
         dummyDB.put(key, val);
     }
 
     /** {@inheritDoc} */
-    @Override public void remove(@Nullable GridCacheTx tx, Long key) throws 
GridException {
+    @Override public void remove(@Nullable GridCacheTx tx, Long key) throws 
IgniteCheckedException {
         System.out.println(">>> Store remove [key=" + key + ", xid=" + (tx == 
null ? null : tx.xid()) + ']');
 
         dummyDB.remove(key);
     }
 
     /** {@inheritDoc} */
-    @Override public void loadCache(IgniteBiInClosure<Long, Person> clo, 
Object... args) throws GridException {
+    @Override public void loadCache(IgniteBiInClosure<Long, Person> clo, 
Object... args) throws IgniteCheckedException {
         int cnt = (Integer)args[0];
 
         System.out.println(">>> Store loadCache for entry count: " + cnt);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/store/hibernate/CacheHibernatePersonStore.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/hibernate/CacheHibernatePersonStore.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/hibernate/CacheHibernatePersonStore.java
index aff470a..b08a7a5 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/hibernate/CacheHibernatePersonStore.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/hibernate/CacheHibernatePersonStore.java
@@ -9,9 +9,9 @@
 
 package org.gridgain.examples.datagrid.store.hibernate;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.examples.datagrid.store.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.store.*;
 import org.hibernate.*;
@@ -42,7 +42,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
     }
 
     /** {@inheritDoc} */
-    @Override public Person load(@Nullable GridCacheTx tx, Long key) throws 
GridException {
+    @Override public Person load(@Nullable GridCacheTx tx, Long key) throws 
IgniteCheckedException {
         System.out.println(">>> Store load [key=" + key + ", xid=" + (tx == 
null ? null : tx.xid()) + ']');
 
         Session ses = session(tx);
@@ -53,7 +53,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
         catch (HibernateException e) {
             rollback(ses, tx);
 
-            throw new GridException("Failed to load value from cache store 
with key: " + key, e);
+            throw new IgniteCheckedException("Failed to load value from cache 
store with key: " + key, e);
         }
         finally {
             end(ses, tx);
@@ -62,7 +62,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
 
     /** {@inheritDoc} */
     @Override public void put(@Nullable GridCacheTx tx, Long key, @Nullable 
Person val)
-        throws GridException {
+        throws IgniteCheckedException {
         System.out.println(">>> Store put [key=" + key + ", val=" + val + ", 
xid=" + (tx == null ? null : tx.xid()) + ']');
 
         if (val == null) {
@@ -79,7 +79,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
         catch (HibernateException e) {
             rollback(ses, tx);
 
-            throw new GridException("Failed to put value to cache store [key=" 
+ key + ", val" + val + "]", e);
+            throw new IgniteCheckedException("Failed to put value to cache 
store [key=" + key + ", val" + val + "]", e);
         }
         finally {
             end(ses, tx);
@@ -88,7 +88,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
 
     /** {@inheritDoc} */
     @SuppressWarnings({"JpaQueryApiInspection"})
-    @Override public void remove(@Nullable GridCacheTx tx, Long key) throws 
GridException {
+    @Override public void remove(@Nullable GridCacheTx tx, Long key) throws 
IgniteCheckedException {
         System.out.println(">>> Store remove [key=" + key + ", xid=" + (tx == 
null ? null : tx.xid()) + ']');
 
         Session ses = session(tx);
@@ -100,7 +100,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
         catch (HibernateException e) {
             rollback(ses, tx);
 
-            throw new GridException("Failed to remove value from cache store 
with key: " + key, e);
+            throw new IgniteCheckedException("Failed to remove value from 
cache store with key: " + key, e);
         }
         finally {
             end(ses, tx);
@@ -108,9 +108,9 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
     }
 
     /** {@inheritDoc} */
-    @Override public void loadCache(IgniteBiInClosure<Long, Person> clo, 
Object... args) throws GridException {
+    @Override public void loadCache(IgniteBiInClosure<Long, Person> clo, 
Object... args) throws IgniteCheckedException {
         if (args == null || args.length == 0 || args[0] == null)
-            throw new GridException("Expected entry count parameter is not 
provided.");
+            throw new IgniteCheckedException("Expected entry count parameter 
is not provided.");
 
         final int entryCnt = (Integer)args[0];
 
@@ -136,7 +136,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
             System.out.println(">>> Loaded " + cnt + " values into cache.");
         }
         catch (HibernateException e) {
-            throw new GridException("Failed to load values from cache store.", 
e);
+            throw new IgniteCheckedException("Failed to load values from cache 
store.", e);
         }
         finally {
             end(ses, null);
@@ -180,7 +180,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
     }
 
     /** {@inheritDoc} */
-    @Override public void txEnd(GridCacheTx tx, boolean commit) throws 
GridException {
+    @Override public void txEnd(GridCacheTx tx, boolean commit) throws 
IgniteCheckedException {
         Session ses = tx.removeMeta(ATTR_SES);
 
         if (ses != null) {
@@ -199,7 +199,7 @@ public class CacheHibernatePersonStore extends 
GridCacheStoreAdapter<Long, Perso
                     System.out.println("Transaction ended [xid=" + tx.xid() + 
", commit=" + commit + ']');
                 }
                 catch (HibernateException e) {
-                    throw new GridException("Failed to end transaction [xid=" 
+ tx.xid() +
+                    throw new IgniteCheckedException("Failed to end 
transaction [xid=" + tx.xid() +
                         ", commit=" + commit + ']', e);
                 }
                 finally {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/datagrid/store/jdbc/CacheJdbcPersonStore.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/jdbc/CacheJdbcPersonStore.java
 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/jdbc/CacheJdbcPersonStore.java
index 315f043..eb52a61 100644
--- 
a/examples/src/main/java/org/gridgain/examples/datagrid/store/jdbc/CacheJdbcPersonStore.java
+++ 
b/examples/src/main/java/org/gridgain/examples/datagrid/store/jdbc/CacheJdbcPersonStore.java
@@ -9,9 +9,9 @@
 
 package org.gridgain.examples.datagrid.store.jdbc;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.examples.datagrid.store.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.store.*;
 import org.jetbrains.annotations.*;
@@ -31,9 +31,9 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
     /**
      * Constructor.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    public CacheJdbcPersonStore() throws GridException {
+    public CacheJdbcPersonStore() throws IgniteCheckedException {
         prepareDb();
     }
 
@@ -41,9 +41,9 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
      * Prepares database for example execution. This method will create a
      * table called "PERSONS" so it can be used by store implementation.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private void prepareDb() throws GridException {
+    private void prepareDb() throws IgniteCheckedException {
         try (Connection conn = openConnection(false); Statement st = 
conn.createStatement()) {
             st.execute("create table if not exists PERSONS (id number unique, 
firstName varchar(255), " +
                 "lastName varchar(255))");
@@ -51,12 +51,12 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
             conn.commit();
         }
         catch (SQLException e) {
-            throw new GridException("Failed to create database table.", e);
+            throw new IgniteCheckedException("Failed to create database 
table.", e);
         }
     }
 
     /** {@inheritDoc} */
-    @Override public void txEnd(GridCacheTx tx, boolean commit) throws 
GridException {
+    @Override public void txEnd(GridCacheTx tx, boolean commit) throws 
IgniteCheckedException {
         try (Connection conn = tx.removeMeta(ATTR_NAME)) {
             if (conn != null) {
                 if (commit)
@@ -68,12 +68,12 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
             System.out.println(">>> Transaction ended [xid=" + tx.xid() + ", 
commit=" + commit + ']');
         }
         catch (SQLException e) {
-            throw new GridException("Failed to end transaction [xid=" + 
tx.xid() + ", commit=" + commit + ']', e);
+            throw new IgniteCheckedException("Failed to end transaction [xid=" 
+ tx.xid() + ", commit=" + commit + ']', e);
         }
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public Person load(@Nullable GridCacheTx tx, Long key) 
throws GridException {
+    @Nullable @Override public Person load(@Nullable GridCacheTx tx, Long key) 
throws IgniteCheckedException {
         System.out.println(">>> Store load [key=" + key + ", xid=" + (tx == 
null ? null : tx.xid()) + ']');
 
         Connection conn = null;
@@ -91,7 +91,7 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
             }
         }
         catch (SQLException e) {
-            throw new GridException("Failed to load object: " + key, e);
+            throw new IgniteCheckedException("Failed to load object: " + key, 
e);
         }
         finally {
             end(tx, conn);
@@ -102,7 +102,7 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
 
     /** {@inheritDoc} */
     @Override public void put(@Nullable GridCacheTx tx, Long key, Person val)
-        throws GridException {
+        throws IgniteCheckedException {
         System.out.println(">>> Store put [key=" + key + ", val=" + val + ", 
xid=" + (tx == null ? null : tx.xid()) + ']');
 
         Connection conn = null;
@@ -134,7 +134,7 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
         }
         }
         catch (SQLException e) {
-            throw new GridException("Failed to put object [key=" + key + ", 
val=" + val + ']', e);
+            throw new IgniteCheckedException("Failed to put object [key=" + 
key + ", val=" + val + ']', e);
         }
         finally {
             end(tx, conn);
@@ -142,7 +142,7 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
     }
 
     /** {@inheritDoc} */
-    @Override public void remove(@Nullable GridCacheTx tx, Long key) throws 
GridException {
+    @Override public void remove(@Nullable GridCacheTx tx, Long key) throws 
IgniteCheckedException {
         System.out.println(">>> Store remove [key=" + key + ", xid=" + (tx == 
null ? null : tx.xid()) + ']');
 
         Connection conn = null;
@@ -157,7 +157,7 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
             }
         }
         catch (SQLException e) {
-            throw new GridException("Failed to remove object: " + key, e);
+            throw new IgniteCheckedException("Failed to remove object: " + 
key, e);
         }
         finally {
             end(tx, conn);
@@ -165,9 +165,9 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
     }
 
     /** {@inheritDoc} */
-    @Override public void loadCache(IgniteBiInClosure<Long, Person> clo, 
Object... args) throws GridException {
+    @Override public void loadCache(IgniteBiInClosure<Long, Person> clo, 
Object... args) throws IgniteCheckedException {
         if (args == null || args.length == 0 || args[0] == null)
-            throw new GridException("Expected entry count parameter is not 
provided.");
+            throw new IgniteCheckedException("Expected entry count parameter 
is not provided.");
 
         final int entryCnt = (Integer)args[0];
 
@@ -193,7 +193,7 @@ public class CacheJdbcPersonStore extends 
GridCacheStoreAdapter<Long, Person> {
             }
         }
         catch (SQLException e) {
-            throw new GridException("Failed to load values from cache store.", 
e);
+            throw new IgniteCheckedException("Failed to load values from cache 
store.", e);
         }
         finally {
             end(null, conn);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/events/EventsExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/events/EventsExample.java 
b/examples/src/main/java/org/gridgain/examples/events/EventsExample.java
index a911ca9..8027b91 100644
--- a/examples/src/main/java/org/gridgain/examples/events/EventsExample.java
+++ b/examples/src/main/java/org/gridgain/examples/events/EventsExample.java
@@ -36,7 +36,7 @@ public class EventsExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
      * @throws GridException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         try (Ignite ignite = 
Ignition.start("examples/config/example-compute.xml")) {
@@ -57,7 +57,7 @@ public class EventsExample {
     /**
      * Listen to events that happen only on local node.
      *
      * @throws GridException If failed.
      */
     private static void localListen() throws Exception {
         System.out.println();
@@ -90,9 +90,9 @@ public class EventsExample {
     /**
      * Listen to events coming from all grid nodes.
      *
      * @throws GridException If failed.
      */
-    private static void remoteListen() throws GridException {
+    private static void remoteListen() throws IgniteCheckedException {
         System.out.println();
         System.out.println(">>> Remote event listener example.");
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsExample.java
----------------------------------------------------------------------
@@ -36,7 +36,7 @@ public class EventsExample {
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
@@ -57,7 +57,7 @@ public class EventsExample {
      * Listen to events that happen only on local node.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     private static void localListen() throws Exception {
@@ -90,9 +90,9 @@ public class EventsExample {
      * Listen to events coming from all grid nodes.
      *
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/examples/src/main/java/org/gridgain/examples/ggfs/GgfsExample.java 
b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsExample.java
index 18d2fbf..b0d7100 100644
--- a/examples/src/main/java/org/gridgain/examples/ggfs/GgfsExample.java
+++ b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsExample.java
@@ -33,7 +33,7 @@ public final class GgfsExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
      * @throws GridException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         Ignite g = 
Ignition.start("examples/config/filesystem/example-ggfs.xml");
@@ -98,9 +98,9 @@ public final class GgfsExample {
      *
      * @param fs GGFS.
      * @param path File or directory path.
      * @throws GridException In case of error.
      */
-    private static void delete(IgniteFs fs, IgniteFsPath path) throws 
GridException {
+    private static void delete(IgniteFs fs, IgniteFsPath path) throws 
IgniteCheckedException {
         assert fs != null;
         assert path != null;
 
@@ -130,9 +130,9 @@ public final class GgfsExample {
      *
      * @param fs GGFS.
      * @param path Directory path.
      * @throws GridException In case of error.
      */
-    private static void mkdirs(IgniteFs fs, IgniteFsPath path) throws 
GridException {
+    private static void mkdirs(IgniteFs fs, IgniteFsPath path) throws 
IgniteCheckedException {
         assert fs != null;
         assert path != null;
 
@@ -156,11 +156,11 @@ public final class GgfsExample {
      * @param fs GGFS.
      * @param path File path.
      * @param data Data.
      * @throws GridException If file can't be created.
      * @throws IOException If data can't be written.
      */
     private static void create(IgniteFs fs, IgniteFsPath path, @Nullable 
byte[] data)
-        throws GridException, IOException {
+        throws IgniteCheckedException, IOException {
         assert fs != null;
         assert path != null;
 
@@ -185,10 +185,10 @@ public final class GgfsExample {
      * @param fs GGFS.
      * @param path File path.
      * @param data Data.
      * @throws GridException If file can't be created.
      * @throws IOException If data can't be written.
      */
-    private static void append(IgniteFs fs, IgniteFsPath path, byte[] data) 
throws GridException, IOException {
+    private static void append(IgniteFs fs, IgniteFsPath path, byte[] data) 
throws IgniteCheckedException, IOException {
         assert fs != null;
         assert path != null;
         assert data != null;
@@ -210,10 +210,10 @@ public final class GgfsExample {
      *
      * @param fs GGFS.
      * @param path File path.
      * @throws GridException If file can't be opened.
      * @throws IOException If data can't be read.
      */
-    private static void read(IgniteFs fs, IgniteFsPath path) throws 
GridException, IOException {
+    private static void read(IgniteFs fs, IgniteFsPath path) throws 
IgniteCheckedException, IOException {
         assert fs != null;
         assert path != null;
         assert fs.info(path).isFile();
@@ -233,9 +233,9 @@ public final class GgfsExample {
      *
      * @param fs GGFS.
      * @param path Directory path.
      * @throws GridException In case of error.
      */
-    private static void list(IgniteFs fs, IgniteFsPath path) throws 
GridException {
+    private static void list(IgniteFs fs, IgniteFsPath path) throws 
IgniteCheckedException {
         assert fs != null;
         assert path != null;
         assert fs.info(path).isDirectory();
@@ -262,9 +262,9 @@ public final class GgfsExample {
      *
      * @param fs GGFS.
      * @param path File or directory path.
      * @throws GridException In case of error.
      */
-    private static void printInfo(IgniteFs fs, IgniteFsPath path) throws 
GridException {
+    private static void printInfo(IgniteFs fs, IgniteFsPath path) throws 
IgniteCheckedException {
         System.out.println();
         System.out.println("Information for " + path + ": " + fs.info(path));
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsMapReduceExample.java
----------------------------------------------------------------------
@@ -33,7 +33,7 @@ public final class GgfsExample {
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
@@ -98,9 +98,9 @@ public final class GgfsExample {
      * @param fs GGFS.
      * @param path File or directory path.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -130,9 +130,9 @@ public final class GgfsExample {
      * @param fs GGFS.
      * @param path Directory path.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -156,11 +156,11 @@ public final class GgfsExample {
      * @param path File path.
      * @param data Data.
-     * @throws GridException If file can't be created.
+     * @throws IgniteCheckedException If file can't be created.
      * @throws IOException If data can't be written.
      */
@@ -185,10 +185,10 @@ public final class GgfsExample {
      * @param path File path.
      * @param data Data.
-     * @throws GridException If file can't be created.
+     * @throws IgniteCheckedException If file can't be created.
      * @throws IOException If data can't be written.
      */
@@ -210,10 +210,10 @@ public final class GgfsExample {
      * @param fs GGFS.
      * @param path File path.
-     * @throws GridException If file can't be opened.
+     * @throws IgniteCheckedException If file can't be opened.
      * @throws IOException If data can't be read.
      */
@@ -233,9 +233,9 @@ public final class GgfsExample {
      * @param fs GGFS.
      * @param path Directory path.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
@@ -262,9 +262,9 @@ public final class GgfsExample {
      * @param fs GGFS.
      * @param path File or directory path.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */
diff --git 
a/examples/src/main/java/org/gridgain/examples/ggfs/GgfsMapReduceExample.java 
b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsMapReduceExample.java
index 2de576a..f73fb28 100644
--- 
a/examples/src/main/java/org/gridgain/examples/ggfs/GgfsMapReduceExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsMapReduceExample.java
@@ -122,12 +122,12 @@ public class GgfsMapReduceExample {
     private static class GrepTask extends IgniteFsTask<String, 
Collection<Line>> {
         /** {@inheritDoc} */
         @Override public IgniteFsJob createJob(IgniteFsPath path, 
IgniteFsFileRange range,
-            IgniteFsTaskArgs<String> args) throws GridException {
+            IgniteFsTaskArgs<String> args) throws IgniteCheckedException {
             return new GrepJob(args.userArgument());
         }
 
         /** {@inheritDoc} */
-        @Override public Collection<Line> reduce(List<ComputeJobResult> 
results) throws GridException {
+        @Override public Collection<Line> reduce(List<ComputeJobResult> 
results) throws IgniteCheckedException {
             Collection<Line> lines = new TreeSet<>(new Comparator<Line>() {
                 @Override public int compare(Line line1, Line line2) {
                     return line1.rangePosition() < line2.rangePosition() ? -1 :
@@ -166,7 +166,7 @@ public class GgfsMapReduceExample {
         }
 
         /**  {@inheritDoc} */
-        @Override public Object execute(IgniteFs ggfs, 
IgniteFsRangeInputStream in) throws GridException, IOException {
+        @Override public Object execute(IgniteFs ggfs, 
IgniteFsRangeInputStream in) throws IgniteCheckedException, IOException {
             Collection<Line> res = null;
 
             long start = in.startOffset();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsNodeStartup.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/ggfs/GgfsNodeStartup.java 
b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsNodeStartup.java
index c4c35aa..48f27ef 100644
--- a/examples/src/main/java/org/gridgain/examples/ggfs/GgfsNodeStartup.java
+++ b/examples/src/main/java/org/gridgain/examples/ggfs/GgfsNodeStartup.java
@@ -26,9 +26,9 @@ public class GgfsNodeStartup {
      * Start up an empty node with specified cache configuration.
      *
      * @param args Command line arguments, none required.
      * @throws GridException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         Ignition.start("examples/config/filesystem/example-ggfs.xml");
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java
----------------------------------------------------------------------
@@ -26,9 +26,9 @@ public class GgfsNodeStartup {
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
diff --git 
a/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java 
b/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java
index 2b6cf80..fa51a78 100644
--- 
a/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/messaging/MessagingExample.java
@@ -43,7 +43,7 @@ public final class MessagingExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
     public static void main(String[] args) throws Exception {
         try (Ignite g = Ignition.start("examples/config/example-compute.xml")) 
{
@@ -92,9 +92,9 @@ public final class MessagingExample {
      * Start listening to messages on all grid nodes within passed in 
projection.
      *
      * @param msg Grid messaging.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
-    private static void startListening(IgniteMessaging msg) throws 
GridException {
+    private static void startListening(IgniteMessaging msg) throws 
IgniteCheckedException {
         // Add ordered message listener.
         msg.remoteListen(TOPIC.ORDERED, new IgniteBiPredicate<UUID, String>() {
             @IgniteInstanceResource
@@ -106,7 +106,7 @@ public final class MessagingExample {
                 try {
                     
g.message(g.cluster().forNodeId(nodeId)).send(TOPIC.ORDERED, msg);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     e.printStackTrace();
                 }
 
@@ -125,7 +125,7 @@ public final class MessagingExample {
                 try {
                     
g.message(g.cluster().forNodeId(nodeId)).send(TOPIC.UNORDERED, msg);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     e.printStackTrace();
                 }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
 
b/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
index faff0c8..ed9585b 100644
--- 
a/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/messaging/MessagingPingPongExample.java
@@ -36,9 +36,9 @@ public class MessagingPingPongExample {
      * Executes example.
      *
      * @param args Command line arguments, none required.
-     * @throws GridException If example execution failed.
+     * @throws IgniteCheckedException If example execution failed.
      */
-    public static void main(String[] args) throws GridException {
+    public static void main(String[] args) throws IgniteCheckedException {
         // Game is played over the default grid.
         try (Ignite g = Ignition.start("examples/config/example-compute.xml")) 
{
             if (!ExamplesUtils.checkMinTopologySize(g.cluster(), 2))
@@ -73,7 +73,7 @@ public class MessagingPingPongExample {
 
                         return false; // Unsubscribe.
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         throw new GridClosureException(e);
                     }
                 }
@@ -105,7 +105,7 @@ public class MessagingPingPongExample {
 
                         return true; // Continue listening.
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         throw new GridClosureException(e);
                     }
                 }

Reply via email to